@@ -177,12 +177,18 @@ def build_run(cmd, files=None, all_files=True, async=False, sync_first=False, ke
     :param sync_first: If true and async is true, the command will run first synchronously,
                        then it will run in async mode.
 
-    :param keep_alive: If non-0, wraps command with a loop that will automatically
-                       re-run the command if it dies, waiting keep_alive seconds between
+    :param keep_alive: If specified, wraps command with a loop that will automatically
+                       re-run the command if it dies. 
+
+                       If keep_alive is an integer, waits keep_alive seconds between
                        each run.  This can be used in two ways:
                        1) making sure a process that shouldn't ever die gets restarted
                        2) make a task that runs periodically every keep_alive seconds
 
+                       If keep_alive is a function, will run the function before
+                       re-running the original command, passing the function
+                       command, args, and kwargs from this call.
+
     :param args: args to pass to run/local commands
 
     :param kwargs: kwarsg to pass to run/local commands
@@ -223,7 +229,12 @@ def build_run(cmd, files=None, all_files=True, async=False, sync_first=False, ke
                     "caused an exception. Restarting after 1 second.".format(command, a, kws)
                 )
             finally:
-                time.sleep(keep_alive)
+                if callable(keep_alive):
+                    # If keep alive is a function, call it
+                    keep_alive(command, *a, **kws)
+                else:
+                    # Else, it hsould be an integer
+                    time.sleep(keep_alive)
 
     run_fn = r
     if keep_alive > 0:
